@@ -5,17 +5,20 @@ verbose=1
 scratchFlag=""
 doRhpkgContainerBuild=1
 forceBuild=0
-# NOTE: pullAssets (-p) flag uses opposite behaviour to some other get-sources.sh scripts;
+# NOTE: --pull-assets (-p) flag uses opposite behaviour to some other get-sources.sh scripts;
 # here we want to collect assets during sync-to-downsteam (using get-sources.sh -n -p)
 # so that rhpkg build is simply a brew wrapper (using get-sources.sh -f)
-pullAssets=0
+PULL_ASSETS=0
 
 while [[ "$#" -gt 0 ]]; do
 	case $1 in
-		'-p'|'--pull-assets') pullAssets=1; shift 0;;
+		'-p'|'--pull-assets') PULL_ASSETS=1; shift 0;;
+		'-a'|'--publish-assets') exit 0; shift 0;;
+		'-d'|'--delete-assets') exit 0; shift 0;;
 		'-n'|'--nobuild') doRhpkgContainerBuild=0; shift 0;;
 		'-f'|'--force-build') forceBuild=1; shift 0;;
 		'-s'|'--scratch') scratchFlag="--scratch"; shift 0;;
+		'-v') CSV_VERSION="$2"; shift 1;;
 	esac
 	shift 1
 done
@@ -26,14 +29,8 @@ function log()
 	echo "$1"
 	fi
 }
-function logn()
-{
-	if [[ ${verbose} -gt 0 ]]; then
-	echo -n "$1"
-	fi
-}
 
-if [[ ${pullAssets} -eq 1 ]]; then 
+if [[ ${PULL_ASSETS} -eq 1 ]]; then 
 	# step one - build the builder image
 	BUILDER=$(command -v podman || true)
 	if [[ ! -x $BUILDER ]]; then
@@ -68,11 +65,11 @@ if [[ ${pullAssets} -eq 1 ]]; then
 	rm -f "asset-vendor-$(uname -m).tgz"
 fi
 
-if [[ $(git diff-index HEAD --) ]] || [[ ${pullAssets} -eq 1 ]]; then
+if [[ $(git diff-index HEAD --) ]] || [[ ${PULL_ASSETS} -eq 1 ]]; then
 	git add vendor bootstrap.Dockerfile || true
 	log "[INFO] Commit new vendor folder"
-	COMMIT_MSG="vendor folder"
-	if [[ $(git commit -s -m "ci: [get sources] ${COMMIT_MSG}" bootstrap.Dockerfile .gitignore vendor) == *"nothing to commit, working tree clean"* ]]; then 
+	COMMIT_MSG="ci: vendor folder"
+	if [[ $(git commit -s -m "${COMMIT_MSG}" bootstrap.Dockerfile .gitignore vendor) == *"nothing to commit, working tree clean"* ]]; then 
 		log "[INFO] No new sources, so nothing to build."
 	elif [[ ${doRhpkgContainerBuild} -eq 1 ]]; then
 		log "[INFO] Push change:"
